0.2.1
=====
- Patch version in order to replace uploaded sdist files on PyPi.


0.2.0
====
- Added the `environ` module.


0.1.2
=====
- Actually fix the MANIFEST.in contents.


0.1.1
=====
- Fixed issue in `MANIFEST.in` which excluded the `requirements.txt` files.


0.1.0
=====
- Initial release
- Added unit tests
- Support for `ndb_json.dump`, `ndb_json.dumps`, and `ndb_json.loads`
